==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/DerivedFromArrayList.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;

using com.db4o.query;

namespace com.db4o.test {

    public class DerivedFromArrayList : ArrayList {
        
        public void storeOne(){
            Add("One");
            Add("Two");
        }

        public void test(){
            Query q = Tester.query();
            q.constrain(typeof(DerivedFromArrayList));
            ObjectSet objectSet = q.execute();
            while(objectSet.hasNext()){
                DerivedFromArrayList dal = (DerivedFromArrayList)objectSet.next();
                dal.Add("Three");
                Tester.store(dal);
            }
            Tester.reOpen();
            q = Tester.query();
            q.constrain(typeof(DerivedFromArrayList));
            objectSet = q.execute();
            while(objectSet.hasNext()){
                DerivedFromArrayList dal = (DerivedFromArrayList)objectSet.next();
                Tester.ensure(dal.Count > 2);
            }
        }
    }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/DerivedFromArrayList.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;

using com.db4o.query;

namespace com.db4o.test {

    public class DerivedFromArrayList : ArrayList {
        
        public void StoreOne(){
            Add("One");
            Add("Two");
        }

        public void Test(){
            Query q = Tester.Query();
            q.Constrain(typeof(DerivedFromArrayList));
            ObjectSet objectSet = q.Execute();
            while(objectSet.HasNext()){
                DerivedFromArrayList dal = (DerivedFromArrayList)objectSet.Next();
                dal.Add("Three");
                Tester.Store(dal);
            }
            Tester.ReOpen();
            q = Tester.Query();
            q.Constrain(typeof(DerivedFromArrayList));
            objectSet = q.Execute();
            while(objectSet.HasNext()){
                DerivedFromArrayList dal = (DerivedFromArrayList)objectSet.Next();
                Tester.Ensure(dal.Count > 2);
            }
        }
    }
}
